@@ -92,23 +92,17 @@ pub async fn interruptible_straight<T, E: From<InterruptError>>(
 
 pub async fn interruptible<T, E: From<InterruptError>>(
     rx: Receiver<()>,
-    f: Arc<Mutex<dyn Future<Output=Result<T, E>> + Unpin>>
+    f: impl Future<Output=Result<T, E>> + Unpin
 ) -> Result<T, E>
 {
-    let f = f.clone();
-    let mut f = f.lock().await;
-    let f = Box::pin(&mut *f);
     interruptible_straight(rx, f).await
 }
 
 pub async fn interruptible_sendable<T, E: From<InterruptError>>(
     rx: Receiver<()>,
-    f: Arc<Mutex<dyn Future<Output=Result<T, E>> + Send + Unpin>>
+    f: impl Future<Output=Result<T, E>> + Send + Unpin
 ) -> Result<T, E>
 {
-    let f = f.clone();
-    let mut f = f.lock().await;
-    let f = Box::pin(&mut *f);
     interruptible_straight(rx, f).await
 }
 
@@ -116,9 +110,7 @@ pub async fn interruptible_sendable<T, E: From<InterruptError>>(
 #[cfg(test)]
 mod tests {
     use std::future::Future;
-    use std::sync::Arc;
     use futures::executor::block_on;
-    use tokio::sync::Mutex;
 
     use crate::{InterruptError, interruptible, interruptible_sendable, broadcast};
 
@@ -154,16 +146,16 @@ mod tests {
         pub async fn g(self) -> Result<u8, MyError> {
             let (_tx, rx) = broadcast::<()>(1);
 
-            interruptible(rx, Arc::new(Mutex::new(Box::pin(async move {
+            interruptible(rx, Box::pin(async move {
                 Ok(123)
-            })))).await
+            })).await
         }
         pub async fn h(self) -> Result<u8, MyError> {
             let (_tx, rx) = broadcast::<()>(1);
 
-            interruptible(rx, Arc::new(Mutex::new(Box::pin(async move {
+            interruptible(rx, Box::pin(async move {
                 Err(AnotherError::new().into())
-            })))).await
+            })).await
         }
     }
 
@@ -184,8 +176,8 @@ mod tests {
         let (_tx, rx) = broadcast::<()>(1);
 
         // Check that `interruptible_sendable(...)` is a `Send` future.
-        let _: &(dyn Future<Output = Result<i32, InterruptError>> + Send) = &interruptible_sendable(rx, Arc::new(Mutex::new(Box::pin(async move {
+        let _: &(dyn Future<Output = Result<i32, InterruptError>> + Send) = &interruptible_sendable(rx, Box::pin(async move {
             Ok(123)
-        }))));
+        }));
     }
 }
